@@ -33,7 +33,8 @@ def settings(request=None):
     """
     from mezzanine.conf import settings
     settings_dict = None
-    if request and cache_installed():
+    cache_settings = request and cache_installed()
+    if cache_settings:
         cache_key = cache_key_prefix(request) + "context-settings"
         settings_dict = cache_get(cache_key)
     if not settings_dict:
@@ -43,7 +44,7 @@ def settings(request=None):
             settings_dict[k] = getattr(settings, k, "")
         for k in DEPRECATED:
             settings_dict[k] = getattr(settings, k, DEPRECATED)
-        if cache_installed():
+        if cache_settings:
             cache_set(cache_key, settings_dict)
     # This is basically the same as the old ADMIN_MEDIA_PREFIX setting,
     # we just use it in a few spots in the admin to optionally load a
